CloudMemcache

Struct CloudMemcache 

pub struct CloudMemcache { /* private fields */ }
Implements a client for the Cloud Memorystore for Memcached API.

Example

use google_cloud_gax::paginator::ItemPaginator as _;
    let client = CloudMemcache::builder().build().await?;
    let parent = "parent_value";
    let mut list = client.list_instances()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }

Service Description

Configures and manages Cloud Memorystore for Memcached instances.

The memcache.googleapis.com service implements the Google Cloud Memorystore for Memcached API and defines the following resource model for managing Memorystore Memcached (also called Memcached below) instances:

  • The service works with a collection of cloud projects, named: /projects/*
  • Each project has a collection of available locations, named: /locations/*
  • Each location has a collection of Memcached instances, named: /instances/*
  • As such, Memcached instances are resources of the form: /projects/{project_id}/locations/{location_id}/instances/{instance_id}

Note that location_id must be a GCP region; for example:

  • projects/my-memcached-project/locations/us-central1/instances/my-memcached

Configuration

To configure CloudMemcache use the with_* methods in the type returned by builder(). The default configuration should work for most applications. Common configuration changes include

  • with_endpoint(): by default this client uses the global default endpoint (https://memcache.googleapis.com). Applications using regional endpoints or running in restricted networks (e.g. a network configured override this default.
  • with_credentials(): by default this client uses Application Default Credentials. Applications using custom authentication may need to override this default.

Pooling and Cloning

CloudMemcache holds a connection pool internally, it is advised to create one and reuse it. You do not need to wrap CloudMemcache in an Rc or Arc to reuse it, because it already uses an Arc internally.

Implementations

Source

impl CloudMemcache

pub fn builder() -> ClientBuilder

Returns a builder for CloudMemcache.

let client = CloudMemcache::builder().build().await?;
pub fn from_stub<T>(stub: T) -> Self
where T: CloudMemcache + 'static,

Creates a new client from the provided stub.

The most common case for calling this function is in tests mocking the client’s behavior.

pub fn list_instances(&self) -> ListInstances

Lists Instances in a given location.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_memcache_v1::Result;
async fn sample(
   client: &CloudMemcache, parent: &str
) -> Result<()> {
    let mut list = client.list_instances()
        .set_parent(parent)
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_instance(&self) -> GetInstance

Gets details of a single Instance.

Example
use google_cloud_memcache_v1::Result;
async fn sample(
   client: &CloudMemcache, name: &str
) -> Result<()> {
    let response = client.get_instance()
        .set_name(name)
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn create_instance(&self) -> CreateInstance

Creates a new Instance in a given location.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_memcache_v1::model::Instance;
use google_cloud_memcache_v1::Result;
async fn sample(
   client: &CloudMemcache, parent: &str
) -> Result<()> {
    let response = client.create_instance()
        .set_parent(parent)
        .set_instance_id("instance_id_value")
        .set_instance(
            Instance::new()/* set fields */
        )
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_instance(&self) -> UpdateInstance

Updates an existing Instance in a given project and location.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_wkt::FieldMask;
use google_cloud_memcache_v1::model::Instance;
use google_cloud_memcache_v1::Result;
async fn sample(
   client: &CloudMemcache, name: &str
) -> Result<()> {
    let response = client.update_instance()
        .set_instance(
            Instance::new().set_name(name)/* set fields */
        )
        .set_update_mask(FieldMask::default().set_paths(["updated.field.path1", "updated.field.path2"]))
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn update_parameters(&self) -> UpdateParameters

Updates the defined Memcached parameters for an existing instance. This method only stages the parameters, it must be followed by ApplyParameters to apply the parameters to nodes of the Memcached instance.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_memcache_v1::Result;
async fn sample(
   client: &CloudMemcache
) -> Result<()> {
    let response = client.update_parameters()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_instance(&self) -> DeleteInstance

Deletes a single Instance.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_memcache_v1::Result;
async fn sample(
   client: &CloudMemcache, name: &str
) -> Result<()> {
    client.delete_instance()
        .set_name(name)
        .poller().until_done().await?;
    Ok(())
}
pub fn apply_parameters(&self) -> ApplyParameters

ApplyParameters restarts the set of specified nodes in order to update them to the current set of parameters for the Memcached Instance.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_memcache_v1::Result;
async fn sample(
   client: &CloudMemcache
) -> Result<()> {
    let response = client.apply_parameters()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn reschedule_maintenance(&self) -> RescheduleMaintenance

Reschedules upcoming maintenance event.

Long running operations

This method is used to start, and/or poll a long-running Operation. The Working with long-running operations chapter in the user guide covers these operations in detail.

Example
use google_cloud_lro::Poller;
use google_cloud_memcache_v1::Result;
async fn sample(
   client: &CloudMemcache
) -> Result<()> {
    let response = client.reschedule_maintenance()
        /* set fields */
        .poller().until_done().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_locations(&self) -> ListLocations

Lists information about the supported locations for this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_memcache_v1::Result;
async fn sample(
   client: &CloudMemcache
) -> Result<()> {
    let mut list = client.list_locations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_location(&self) -> GetLocation

Gets information about a location.

Example
use google_cloud_memcache_v1::Result;
async fn sample(
   client: &CloudMemcache
) -> Result<()> {
    let response = client.get_location()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn list_operations(&self) -> ListOperations

Provides the Operations service functionality in this service.

Example
use google_cloud_gax::paginator::ItemPaginator as _;
use google_cloud_memcache_v1::Result;
async fn sample(
   client: &CloudMemcache
) -> Result<()> {
    let mut list = client.list_operations()
        /* set fields */
        .by_item();
    while let Some(item) = list.next().await.transpose()? {
        println!("{:?}", item);
    }
    Ok(())
}
pub fn get_operation(&self) -> GetOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_memcache_v1::Result;
async fn sample(
   client: &CloudMemcache
) -> Result<()> {
    let response = client.get_operation()
        /* set fields */
        .send().await?;
    println!("response {:?}", response);
    Ok(())
}
pub fn delete_operation(&self) -> DeleteOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_memcache_v1::Result;
async fn sample(
   client: &CloudMemcache
) -> Result<()> {
    client.delete_operation()
        /* set fields */
        .send().await?;
    Ok(())
}
pub fn cancel_operation(&self) -> CancelOperation

Provides the Operations service functionality in this service.

Example
use google_cloud_memcache_v1::Result;
async fn sample(
   client: &CloudMemcache
) -> Result<()> {
    client.cancel_operation()
        /* set fields */
        .send().await?;
    Ok(())
}