#[non_exhaustive]pub struct ListInstancesRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
Request for ListInstances.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the instance location using the form:
projects/{project_id}/locations/{location_id}
where location_id refers to a GCP region
page_size: i32The maximum number of items to return.
If not specified, a default value of 1000 will be used by the service.
Regardless of the page_size value, the response may include a partial
list and a caller should only rely on response’s
next_page_token
to determine if there are more instances left to be queried.
page_token: StringThe next_page_token value returned from a previous List request, if any.
filter: StringList filter. For example, exclude all Memcached instances with name as
my-instance by specifying "name != my-instance".
order_by: StringSort results. Supported values are “name”, “name desc” or “” (unsorted).
Implementations
Sourceimpl ListInstancesRequest
impl ListInstancesRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListInstancesRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self